==> G32996_01.zip: troubleshoot/toc.js <==
define(
{
    
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Preface",
                    "href":"preface.html#GUID-917DAF6A-60D2-4089-B706-42B593E96563"
                },
                {
                    "title":"Part I General Java Troubleshooting",
                    "href":"general-java-troubleshooting.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">1 </span> Prepare Java for Troubleshooting",
                            "href":"prepare-java-troubleshooting.html#GUID-28AFFE4C-4526-4C1F-9C47-32D669BCAF1E"
                        },
                        {
                            "title":"<span class=\"secnum\">2 </span> Diagnostic Tools",
                            "href":"diagnostic-tools.html#GUID-CBC97A20-7379-4762-BA17-FB1A560D02E4"
                        },
                        {
                            "title":"<span class=\"secnum\">3 </span> Troubleshoot Memory Leaks",
                            "href":"troubleshooting-memory-leaks.html#GUID-8090B138-6E0C-4926-9659-BE739062AB75"
                        },
                        {
                            "title":"<span class=\"secnum\">4 </span> Troubleshoot Performance Issues Using Flight Recorder",
                            "href":"troubleshoot-performance-issues-using-jfr.html#GUID-0FE29092-18B5-4BEB-8D8D-0CBA7A4FEA1D"
                        },
                        {
                            "title":"<span class=\"secnum\">5 </span> Troubleshoot Security APIs",
                            "href":"troubleshoot-security-apis.html#GUID-BEB4C1C3-8264-45FA-B419-ADC721170DFB"
                        }
                    ]
                },
                {
                    "title":"Part II Debug JVM Issues",
                    "href":"debug-jvm-issues.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">6 </span> Troubleshoot System Crashes",
                            "href":"troubleshoot-system-crashes.html#GUID-BDA1D041-355C-4C85-9ED0-E2AC46D67BED"
                        },
                        {
                            "title":"<span class=\"secnum\">7 </span> Troubleshoot Process Hangs and Loops",
                            "href":"troubleshoot-process-hangs-and-loops.html#GUID-0777035D-123C-4DC5-A241-21560882C7BB"
                        },
                        {
                            "title":"<span class=\"secnum\">8 </span> Handle Signals and Exceptions",
                            "href":"handle-signals-and-exceptions.html#GUID-CBA7BA16-F89F-4BE2-B653-139BABA997D4"
                        }
                    ]
                },
                {
                    "title":"Part III Debug Core Library Issues",
                    "href":"debug-core-library-issues.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">9 </span> Time Zone Settings in the JRE",
                            "href":"time-zone-settings-jre.html#GUID-A92BF4C5-928F-4F64-B3DE-588B630B4A5F"
                        }
                    ]
                },
                {
                    "title":"Part IV Debug Client Issues",
                    "href":"debug-client-issues.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">10 </span> Introduction to Client Issues",
                            "href":"introduction-client-issues.html#GUID-16FFEDCA-9F90-42E5-9979-586CDEDFB34F"
                        },
                        {
                            "title":"<span class=\"secnum\">11 </span> AWT",
                            "href":"awt.html#GUID-E2C5A322-F6BA-4D25-BC2F-D946B10BC581"
                        },
                        {
                            "title":"<span class=\"secnum\">12 </span> Java 2D Pipeline Rendering and Properties",
                            "href":"java-2d-pipeline-rendering-selection-and-properties.html#GUID-DEA4F3FC-87F5-4196-A295-30A559982B10"
                        },
                        {
                            "title":"<span class=\"secnum\">13 </span> Java 2D",
                            "href":"java-2d.html#GUID-63FAD092-E3E7-416D-9CA3-25BBACFC46E9"
                        },
                        {
                            "title":"<span class=\"secnum\">14 </span> Swing",
                            "href":"swing.html#GUID-F09B98F1-AA52-49FB-B695-3BC0754860CD"
                        },
                        {
                            "title":"<span class=\"secnum\">15 </span> Internationalization",
                            "href":"internationalization.html#GUID-B96181A3-4F7F-49DB-9CA1-4DFCE5B024F3"
                        },
                        {
                            "title":"<span class=\"secnum\">16 </span> Java Sound",
                            "href":"java-sound.html#GUID-A2CD7669-9CF4-4002-B4F3-67525BE075B2"
                        }
                    ]
                },
                {
                    "title":"Part V Submit Bug Reports",
                    "href":"submit-bug-reports.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">17 </span> Submit a Bug Report",
                            "href":"submit-bug-report.html#GUID-DB465A9C-03FA-4324-BFF9-45BF9699F349"
                        }
                    ]
                },
                {
                    "title":"Appendices",
                    "href":"appendix.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">A </span> Fatal Error Log",
                            "href":"location-fatal-error-log.html#GUID-2AE5EE08-A68F-4514-9618-A581C0EDFB1B"
                        },
                        {
                            "title":"<span class=\"secnum\">B </span> Java 2D Properties",
                            "href":"java-2d-properties.html#GUID-2DC38ED7-7F26-4489-B3B5-C3B0B31E2786"
                        },
                        {
                            "title":"<span class=\"secnum\">C </span> Environment Variables and System Properties",
                            "href":"environment-variables-and-system-properties.html#GUID-A91E7E21-2E91-48C4-89A4-836A7C0EE93B"
                        },
                        {
                            "title":"<span class=\"secnum\">D </span> Command-Line Options",
                            "href":"command-line-options1.html#GUID-A84ECBFB-B6CF-44C3-B627-58BB509C8D05"
                        },
                        {
                            "title":"<span class=\"secnum\">E </span> Summary of Tools in This Release",
                            "href":"summary-tools-this-release.html#GUID-89566FBC-1E10-4B91-849B-3DD0590BDD84"
                        }
                    ]
                }
            ]
        }
    ]
});

==> G44113_01.zip: troubleshoot/toc.js <==
define(
{
    
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Preface",
                    "href":"preface.html#GUID-917DAF6A-60D2-4089-B706-42B593E96563"
                },
                {
                    "title":"Part I General Java Troubleshooting",
                    "href":"general-java-troubleshooting.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">1 </span> Prepare Java for Troubleshooting",
                            "href":"prepare-java-troubleshooting.html#GUID-28AFFE4C-4526-4C1F-9C47-32D669BCAF1E"
                        },
                        {
                            "title":"<span class=\"secnum\">2 </span> Diagnostic Tools",
                            "href":"diagnostic-tools.html#GUID-CBC97A20-7379-4762-BA17-FB1A560D02E4"
                        },
                        {
                            "title":"<span class=\"secnum\">3 </span> Troubleshoot Memory Leaks",
                            "href":"troubleshooting-memory-leaks.html#GUID-8090B138-6E0C-4926-9659-BE739062AB75"
                        },
                        {
                            "title":"<span class=\"secnum\">4 </span> Troubleshoot Performance Issues Using Flight Recorder",
                            "href":"troubleshoot-performance-issues-using-jfr.html#GUID-0FE29092-18B5-4BEB-8D8D-0CBA7A4FEA1D"
                        },
                        {
                            "title":"<span class=\"secnum\">5 </span> Troubleshoot Security APIs",
                            "href":"troubleshoot-security-apis.html#GUID-BEB4C1C3-8264-45FA-B419-ADC721170DFB"
                        }
                    ]
                },
                {
                    "title":"Part II Debug JVM Issues",
                    "href":"debug-jvm-issues.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">6 </span> Troubleshoot System Crashes",
                            "href":"troubleshoot-system-crashes.html#GUID-BDA1D041-355C-4C85-9ED0-E2AC46D67BED"
                        },
                        {
                            "title":"<span class=\"secnum\">7 </span> Troubleshoot Process Hangs and Loops",
                            "href":"troubleshoot-process-hangs-and-loops.html#GUID-0777035D-123C-4DC5-A241-21560882C7BB"
                        },
                        {
                            "title":"<span class=\"secnum\">8 </span> Handle Signals and Exceptions",
                            "href":"handle-signals-and-exceptions.html#GUID-CBA7BA16-F89F-4BE2-B653-139BABA997D4"
                        }
                    ]
                },
                {
                    "title":"Part III Debug Core Library Issues",
                    "href":"debug-core-library-issues.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">9 </span> Time Zone Settings in the JRE",
                            "href":"time-zone-settings-jre.html#GUID-A92BF4C5-928F-4F64-B3DE-588B630B4A5F"
                        }
                    ]
                },
                {
                    "title":"Part IV Debug Client Issues",
                    "href":"debug-client-issues.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">10 </span> Introduction to Client Issues",
                            "href":"introduction-client-issues.html#GUID-16FFEDCA-9F90-42E5-9979-586CDEDFB34F"
                        },
                        {
                            "title":"<span class=\"secnum\">11 </span> AWT",
                            "href":"awt.html#GUID-E2C5A322-F6BA-4D25-BC2F-D946B10BC581"
                        },
                        {
                            "title":"<span class=\"secnum\">12 </span> Java 2D Pipeline Rendering Selection and Properties",
                            "href":"java-2d-pipeline-rendering-selection-and-properties.html#GUID-DEA4F3FC-87F5-4196-A295-30A559982B10"
                        },
                        {
                            "title":"<span class=\"secnum\">13 </span> Java 2D",
                            "href":"java-2d.html#GUID-63FAD092-E3E7-416D-9CA3-25BBACFC46E9"
                        },
                        {
                            "title":"<span class=\"secnum\">14 </span> Swing",
                            "href":"swing.html#GUID-F09B98F1-AA52-49FB-B695-3BC0754860CD"
                        },
                        {
                            "title":"<span class=\"secnum\">15 </span> Internationalization",
                            "href":"internationalization.html#GUID-B96181A3-4F7F-49DB-9CA1-4DFCE5B024F3"
                        },
                        {
                            "title":"<span class=\"secnum\">16 </span> Java Sound",
                            "href":"java-sound.html#GUID-A2CD7669-9CF4-4002-B4F3-67525BE075B2"
                        }
                    ]
                },
                {
                    "title":"Part V Submit Bug Reports",
                    "href":"submit-bug-reports.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">17 </span> Submit a Bug Report",
                            "href":"submit-bug-report.html#GUID-DB465A9C-03FA-4324-BFF9-45BF9699F349"
                        }
                    ]
                },
                {
                    "title":"Appendices",
                    "href":"appendix.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">A </span> Fatal Error Log",
                            "href":"location-fatal-error-log.html#GUID-2AE5EE08-A68F-4514-9618-A581C0EDFB1B"
                        },
                        {
                            "title":"<span class=\"secnum\">B </span> Java 2D Properties",
                            "href":"java-2d-properties.html#GUID-2DC38ED7-7F26-4489-B3B5-C3B0B31E2786"
                        },
                        {
                            "title":"<span class=\"secnum\">C </span> Environment Variables and System Properties",
                            "href":"environment-variables-and-system-properties.html#GUID-A91E7E21-2E91-48C4-89A4-836A7C0EE93B"
                        },
                        {
                            "title":"<span class=\"secnum\">D </span> Command-Line Options",
                            "href":"command-line-options1.html#GUID-A84ECBFB-B6CF-44C3-B627-58BB509C8D05"
                        },
                        {
                            "title":"<span class=\"secnum\">E </span> Summary of Tools in This Release",
                            "href":"summary-tools-this-release.html#GUID-89566FBC-1E10-4B91-849B-3DD0590BDD84"
                        }
                    ]
                }
            ]
        }
    ]
});
